@@ -613,14 +613,14 @@ compute_distance (const PangoFontDescription *a,
 {
   if (a->style == b->style)
     {
-      return abs(a->weight - b->weight);
+      return abs((int)(a->weight) - (int)(b->weight));
     }
   else if (a->style != PANGO_STYLE_NORMAL &&
 	   b->style != PANGO_STYLE_NORMAL)
     {
       /* Equate oblique and italic, but with a big penalty
        */
-      return 1000000 + abs (a->weight - b->weight);
+      return 1000000 + abs ((int)(a->weight) - (int)(b->weight));
     }
   else
     return G_MAXINT;
@@ -1188,7 +1188,7 @@ append_field (GString *str, const char *what, const FieldMap *map, int n_element
       if (map[i].value != val)
         continue;
 
-      if (G_LIKELY (map[i].str && map[i].str[0]))
+      if (G_LIKELY (map[i].str[0]))
 	{
 	  if (G_LIKELY (str->len > 0 && str->str[str->len -1] != ' '))
 	    g_string_append_c (str, ' ');
